==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/General/rgscan/translations/rgscan_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>Analyseur ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="84"/>
        <source>Write track gain/peak</source>
        <translation>Écrire gain et pic du morceau</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="42"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="47"/>
        <source>Progress</source>
        <translation>Progrès</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="52"/>
        <source>Track Gain</source>
        <translation>Gain du morceau</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="57"/>
        <source>Album Gain</source>
        <translation>Gain de l&apos;album</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="62"/>
        <source>Track Peak</source>
        <translation>Pic du morceau</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="67"/>
        <source>Album Peak</source>
        <translation>Pic de l&apos;album</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="77"/>
        <source>Skip already scanned files</source>
        <translation>Sauter les fichiers déjà analysés</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="113"/>
        <source>Calculate</source>
        <translation>Calculer</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="120"/>
        <source>Write Tags</source>
        <translation>Écrire les étiquettes</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="91"/>
        <source>Write album gain/peak</source>
        <translation>Écrire gain et pic et l&apos;album</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="122"/>
        <location filename="../rgscandialog.cpp" line="233"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="132"/>
        <location filename="../rgscandialog.cpp" line="133"/>
        <location filename="../rgscandialog.cpp" line="157"/>
        <location filename="../rgscandialog.cpp" line="228"/>
        <source>%1 dB</source>
        <translation>%1 dB</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="28"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>Greffon analyseur ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="49"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>À propos du greffon analyseur ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>Greffon analyseur ReplayGain pour Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>Ce greffon analyse les fichiers audio pour obtenir des information de normalisation du volume</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Based on source code by:</source>
        <translation>Basé sur le code source par :</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation>David Robinson &lt;David@Robinson.org&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Frank Klemm</source>
        <translation>Frank Klemm</translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>Analyseur ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation>Meta+R</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/General/rgscan/translations/rgscan_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>Analyseur ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="84"/>
        <source>Write track gain/peak</source>
        <translation>Écrire gain et pic du morceau</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="42"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="47"/>
        <source>Progress</source>
        <translation>Progrès</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="52"/>
        <source>Track Gain</source>
        <translation>Gain du morceau</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="57"/>
        <source>Album Gain</source>
        <translation>Gain de l&apos;album</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="62"/>
        <source>Track Peak</source>
        <translation>Pic du morceau</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="67"/>
        <source>Album Peak</source>
        <translation>Pic de l&apos;album</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="77"/>
        <source>Skip already scanned files</source>
        <translation>Sauter les fichiers déjà analysés</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="113"/>
        <source>Calculate</source>
        <translation>Calculer</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="120"/>
        <source>Write Tags</source>
        <translation>Écrire les étiquettes</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="91"/>
        <source>Write album gain/peak</source>
        <translation>Écrire gain et pic et l&apos;album</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="127"/>
        <location filename="../rgscandialog.cpp" line="233"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="137"/>
        <location filename="../rgscandialog.cpp" line="138"/>
        <location filename="../rgscandialog.cpp" line="163"/>
        <location filename="../rgscandialog.cpp" line="228"/>
        <source>%1 dB</source>
        <translation>%1 dB</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="28"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>Greffon analyseur ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="49"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>À propos du greffon analyseur ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>Greffon analyseur ReplayGain pour Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>Ce greffon analyse les fichiers audio pour obtenir des information de normalisation du volume</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Based on source code by:</source>
        <translation>Basé sur le code source par&#xa0;:</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation>David Robinson &lt;David@Robinson.org&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Frank Klemm</source>
        <translation>Frank Klemm</translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>Analyseur ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation>Meta+R</translation>
    </message>
</context>
</TS>
